@@ -2,11 +2,12 @@
 import os
 from datetime import datetime, timedelta, timezone
 
-__version__ = '0.1.6'
+__version__ = '0.1.9'
 
 
 class Tsd2Gspread():
     def __init__(self, config_file=None, **kw):
+        self.log = None
         self.data = None
         self.service_account = None
         self.sheet_name = None
@@ -32,7 +33,7 @@ class Tsd2Gspread():
         self.gc = None
 
     def get_data_wrapper(self, force=True):
-        if self.data is not None and not self.force:
+        if self.data is not None and not force:
             return self.data
         self.data = self.get_data()
         return self.data
@@ -124,9 +125,9 @@ class Tsd2Gspread():
         self.set_columns(worksheet)
         return worksheet
 
-    def get_tsd(self, data=None):
+    def get_tsd(self, data=None, force=True):
         if data is None:
-            data = self.get_data_wrapper()
+            data = self.get_data_wrapper(force)
         if not data:
             print('failed to get data')
             return False
@@ -140,14 +141,21 @@ class Tsd2Gspread():
             data = [now] + data
         return data
 
-    def write(self, data=None):
-        data = self.get_tsd(data)
+    def write(self, data=None, force=True):
+        data = self.get_tsd(data, force)
         if not data:
             return False
         worksheet = self.get_worksheet()
         worksheet.append_row(data, value_input_option=self.value_input_option)
+        if self.log:
+            with open(self.log, 'w') as f:
+                f.write(self.log_text(data, force=False))
         return True
 
+    def log_text(self, data=None, force=True):
+        data = self.get_tsd(data, force)
+        return ','.join(data)
+
 
 def get(**kw):
     return Tsd2Gspread(**kw)
